obelisk.types.Datapoint
=======================

.. currentmodule:: obelisk.types

.. autoclass:: Datapoint
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Datapoint.__init__
      ~Datapoint.construct
      ~Datapoint.copy
      ~Datapoint.dict
      ~Datapoint.from_orm
      ~Datapoint.json
      ~Datapoint.model_construct
      ~Datapoint.model_copy
      ~Datapoint.model_dump
      ~Datapoint.model_dump_json
      ~Datapoint.model_json_schema
      ~Datapoint.model_parametrized_name
      ~Datapoint.model_post_init
      ~Datapoint.model_rebuild
      ~Datapoint.model_validate
      ~Datapoint.model_validate_json
      ~Datapoint.model_validate_strings
      ~Datapoint.parse_file
      ~Datapoint.parse_obj
      ~Datapoint.parse_raw
      ~Datapoint.schema
      ~Datapoint.schema_json
      ~Datapoint.update_forward_refs
      ~Datapoint.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Datapoint.model_computed_fields
      ~Datapoint.model_config
      ~Datapoint.model_extra
      ~Datapoint.model_fields
      ~Datapoint.model_fields_set
      ~Datapoint.timestamp
      ~Datapoint.value
      ~Datapoint.dataset
      ~Datapoint.metric
      ~Datapoint.source
      ~Datapoint.userId
   
   